@@ -17,8 +17,8 @@
 //! If you are supporting Windows in any capacity, the [`is_windows_10()`] documentation is
 //! **required reading**.
 
-#![doc(html_favicon_url = "https://raw.githubusercontent.com/watchexec/clearscreen/main/logo.png")]
-#![doc(html_logo_url = "https://raw.githubusercontent.com/watchexec/clearscreen/main/logo.png")]
+#![doc(html_favicon_url = "https://raw.githubusercontent.com/watchexec/clearscreen/main/logo.svg")]
+#![doc(html_logo_url = "https://raw.githubusercontent.com/watchexec/clearscreen/main/logo.svg")]
 #![warn(missing_docs)]
 
 use std::{
@@ -326,43 +326,87 @@ impl Default for ClearScreen {
 	/// you wish to only clear the screen and not the scrollback, or to perform a terminal reset, or
 	/// apply the other available clearing strategies, you’ll need to select what’s best yourself.
 	///
-	/// The current behaviour is:
+	/// See the [TERMINALS.md file in the repo][TERMINALS.md] for research on many terminals as well
+	/// as the current result of this function for each terminal.
 	///
-	/// - if compiled for windows (`cfg(windows)`):
-	///   - if we’re running in the Microsoft Terminal, [`XtermClear`][ClearScreen::XtermClear].
-	///   - or if we’re running in Windows 10, [`WindowsVtClear`][ClearScreen::WindowsVtClear].
-	///   - or if both `TERM` and `TERMINFO` are set, [`Terminfo`][ClearScreen::Terminfo].
-	///   - or if `TERM` is set and `tput` is available on the `PATH`, [`TputClear`][ClearScreen::TputClear].
-	///   - otherwise, [`Cls`][ClearScreen::Cls], for now (it should be WindowsConsoleClear but I haven’t tested properly on Win 8).
-	/// - otherwise (i.e. this is unix or unix-compatible):
-	///   - if `TERM_PROGRAM=iTerm.app` and `TERM` starts with `xterm`, [`XtermClear`][ClearScreen::XtermClear]
-	///     (iTerm doesn’t have its own terminfo, and uses xterm’s, but the xterm terminfo file on
-	///     macOS doesn’t have the E3 Erase Scrollback entry, even though iTerm supports it).
-	///   - if `TERM` is set, [`Terminfo`][ClearScreen::Terminfo].
-	///   - otherwise, [`XtermClear`][ClearScreen::XtermClear].
+	/// [TERMINALS.md]: https://github.com/watchexec/clearscreen/blob/main/TERMINALS.md
 	fn default() -> Self {
+		use env::var;
+		use std::ffi::OsStr;
+
+		fn varfull(key: impl AsRef<OsStr>) -> bool {
+			var(key).map_or(false, |s| !s.is_empty())
+		}
+
+		let term = var("TERM").ok();
+		let term = term.as_ref();
+		let term_program = var("TERM_PROGRAM").ok();
+		let term_program = term_program.as_ref();
+		let terminfo = varfull("TERMINFO");
+
 		if cfg!(windows) {
 			return if is_microsoft_terminal() {
 				Self::XtermClear
 			} else if is_windows_10() {
 				Self::WindowsVtClear
-			} else if env::var("TERM").is_ok() && env::var("TERMINFO").is_ok() {
+			} else if term.is_some() && terminfo {
 				Self::Terminfo
-			} else if env::var("TERM").is_ok() && which("tput").is_ok() {
+			} else if term.is_some() && which("tput").is_ok() {
 				Self::TputClear
 			} else {
 				Self::Cls
 			};
 		}
 
-		if let (Ok(term), Ok(termp)) = (env::var("TERM"), env::var("TERM_PROGRAM")) {
-			if term.starts_with("xterm") && termp == "iTerm.app" {
+		if let Some(term) = term {
+			if let Some(termp) = term_program {
+				// iTerm2 supports CSI 3J but macOS’s xterm-256color terminfo (its default) doesn’t have E3
+				if term.starts_with("xterm") && termp == "iTerm.app" {
+					return Self::XtermClear;
+				}
+			}
+
+			// These VTE-based terminals support CSI 3J but their own terminfos don’t have E3
+			if (term.starts_with("gnome")
+				&& varfull("GNOME_TERMINAL_SCREEN")
+				&& varfull("GNOME_TERMINAL_SERVICE"))
+				|| term == "xfce"
+				|| term.contains("termite")
+			{
 				return Self::XtermClear;
 			}
-		}
 
-		if env::var("TERM").is_ok() {
-			return Self::Terminfo;
+			// - SyncTERM does support the XtermClear sequence but does not clear the scrollback,
+			// and does not have a terminfo, so VtRis is the only option.
+			// - rxvt, when using its own terminfos, erases the screen instead of clearing and
+			// doesn’t clear scrollback. It supports and behave properly for the entire XtermClear
+			// sequence, but it also does the right thing with VtRis, and that seems more reliable.
+			// - Other variants of (u)rxvt do the same.
+			// - Kitty does as rxvt does here.
+			// - Tess does support the XtermClear sequence but has a weird scrollbar behaviour,
+			// which does not happen with VtRis.
+			// - Zutty does not support E3, and erases the buffer on clear like rxvt, but does work
+			// properly with VtRis.
+			// - Same behaviour with the multiplexer Zellij.
+			if term == "syncterm"
+				|| term.contains("rxvt")
+				|| term.contains("kitty")
+				|| var("CHROME_DESKTOP").map_or(false, |cd| cd == "tess.desktop")
+				|| varfull("ZUTTY_VERSION")
+				|| varfull("ZELLIJ")
+			{
+				return Self::VtRis;
+			}
+
+			// - screen supports CSI 3J only within the XtermClear sequence, without E3 capability.
+			// - Konsole handles CSI 3J correctly only within the XtermClear sequence.
+			if term.starts_with("screen") || term.starts_with("konsole") {
+				return Self::XtermClear;
+			}
+
+			if !term.is_empty() {
+				return Self::Terminfo;
+			}
 		}
 
 		Self::XtermClear
